jactorch.vision.gradient
========================

.. automodule:: jactorch.vision.gradient

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      ImageGradient
      Laplacian
      Scharr
      Sobel
      SobelBase
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      image_gradient
      laplacian
      scharr
      sobel
   
   

   
   
   








.. rubric:: Class ImageGradient
.. autoclass:: ImageGradient
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Laplacian
.. autoclass:: Laplacian
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Scharr
.. autoclass:: Scharr
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Sobel
.. autoclass:: Sobel
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class SobelBase
.. autoclass:: SobelBase
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: image_gradient

.. autofunction:: laplacian

.. autofunction:: scharr

.. autofunction:: sobel


